@@ -6,7 +6,7 @@ import time
 import datetime
 import logging
 from typing import Dict
-
+import functools
 from aliyunsdkecs.request.v20140526 import DescribeInstancesRequest, DescribeInstanceAttributeRequest, DescribeDisksRequest, \
     DescribeInstanceTypesRequest, AllocatePublicIpAddressRequest, StartInstanceRequest, DescribeVpcsRequest, AddTagsRequest, JoinSecurityGroupRequest, \
     StopInstanceRequest, ModifyInstanceSpecRequest, ModifyPrepayInstanceSpecRequest
@@ -22,6 +22,25 @@ from aliyunsdkcore.acs_exception.exceptions import ClientException
 
 logger = logging.getLogger(__name__)
 
+def retry(loop=3,delay=5):
+    def trace(func):
+        @functools.wraps(func)
+        def wrapper(*args, **kwargs):
+            for i in range(1,loop+1):
+                logger.debug(f'第{i}次請求', args, kwargs)
+                try:
+                    return func(*args, **kwargs)
+                except ClientException as e:
+                    logger.warning(f'超時 重試第{i}次 {e}')
+                    time.sleep(delay)
+                except Exception as e:
+                    logger.warning(f'重試第{i}次 {e} {args} {kwargs}')
+                    time.sleep(delay)
+
+        return wrapper
+
+    return trace
+
 
 class Base:
     pagesize = 100
@@ -31,27 +50,12 @@ class Base:
         self.client = AcsClient(ACCESS_KEY_ID, ACCESS_KEY_SECRET, REGION_ID)
         self.ins_list = []
 
+    @retry()
     def do_action(self, request):
-        status = False
-
-        for i in range(1, 4):
-            try:
-                # request.set_accept_format('json')
-                response = self.client.do_action_with_exception(request)
-                response = json.loads(str(response, encoding='utf-8'))
-                logger.debug(response)
-                status = True
-                return response
-            except ClientException as e:
-                print('超時 請求重試 等待10秒 {}'.format(e))
-                logger.error('超時 請求重試 等待10秒 {}'.format(e))
-                time.sleep(10)
-            except Exception as e:
-                print(f"未知錯誤 請求重試 {e}")
-
-        if not status:
-            logger.error('多次請求錯誤')
-            raise Exception('多次請求錯誤')
+        response = self.client.do_action_with_exception(request)
+        response = json.loads(str(response, encoding='utf-8'))
+        logger.debug(response)
+        return response
 
     def get_totel_page(self, request):
         request.set_PageSize(1)
